# PIDGen2 

## Introduction

PIDGen is a tool to resample PID variables in the full MC bases on distributions from calibration samples. PIDGen2 is a successor of the old PIDGen package. PIDGen2 is available via `lb-conda` and is supposed to replace the old PIDGen, both for Run 3 data, and for Run 1/Run 2. 

## Documentation

See [documentation pages here](https://gitlab.cern.ch/lhcb-rta/pidgen2/-/tree/master/doc). 

## Links

   * 12/10/21, Run 1/2 performance WG meeting, [PIDGen2](https://indico.cern.ch/event/1084372/#24-news-on-pidgen2)
   * 11/02/21, RTA WP4-5 meeting, [PIDGen in Run3](https://indico.cern.ch/event/997930/#3-new-pidgencorr)
   * [Twiki for the old PIDGen/PIDCorr for Run1/2](https://twiki.cern.ch/twiki/bin/view/LHCb/MeerkatPIDResampling)
   * Details about Run2 PID calibration samples are here: [ChargedPID twiki](https://twiki.cern.ch/twiki/bin/viewauth/LHCbPhysics/ChargedPID)
   * [LHCb-INT-2017-007 internal note](https://gitlab.cern.ch/lhcb-docs/INT/LHCb-INT-2017-007/blob/master/drafts/LHCb-INT-2017-007_v0r0.pdf) describing the PIDGen/PIDCorr procedure used in Run1/2. 

